@@ -305,6 +305,8 @@ class CrudManager(Manager):
 
         If a `base_url` is provided, the generated URL will be appended to it.
 
+        If a 'tail' is provided, it will be appended to the end of the URL.
+
         """
         if dict_args_in_out is None:
             dict_args_in_out = {}
@@ -317,6 +319,9 @@ class CrudManager(Manager):
         if entity_id is not None:
             url += '/%s' % entity_id
 
+        if dict_args_in_out.get('tail'):
+            url += dict_args_in_out['tail']
+
         return url
 
     @filter_kwargs
@@ -340,6 +345,15 @@ class CrudManager(Manager):
     def _build_query(self, params):
         return '?%s' % urllib.parse.urlencode(params) if params else ''
 
+    def build_key_only_query(self, params_list):
+        """Builds a query that does not include values, just keys.
+
+        The Identity API has some calls that define queries without values,
+        this can not be accomplished by using urllib.parse.urlencode(). This
+        method builds a query using only the keys.
+        """
+        return '?%s' % '&'.join(params_list) if params_list else ''
+
     @filter_kwargs
     def list(self, fallback_to_auth=False, **kwargs):
         url = self.build_url(dict_args_in_out=kwargs)
